@@ -6,6 +6,9 @@
 /* Set to 1 if you have xz */
 #define HAVE_XZ_SUPPORT 1
 
+/* Set to 1 if you have openssl */
+#define HAVE_OPENSSL_SUPPORT 1
+
 /* Set to 1 if you have zstd */
 #define HAVE_ZSTD_SUPPORT 1
 
